==> haskell-stm-containers-1.2.1.1-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-containers
version:              1.2.1.1
visibility:           public
id:                   stm-containers-1.2.1.1-EtSXtMDXMlVGWKUw1ZLk6p
key:                  stm-containers-1.2.1.1-EtSXtMDXMlVGWKUw1ZLk6p
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  6b62d1c3b4dd8dc89fc8d303154941c2
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.1.1-EtSXtMDXMlVGWKUw1ZLk6p
depends:
    base-4.17.2.1 deferred-folds-0.9.18.6-HtaMriOUSPK6fN8KfiZp7
    focus-1.0.3.2-KaP0q2s4xqF1lVNITPnSzF
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    list-t-1.0.5.5-8lXUI1ymNIM7UUyeY3sOQP
    stm-hamt-1.2.1-DMsQA8Z2tThE5M0x2QP3IF transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-containers-1.2.1.1-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-containers
version:              1.2.1.1
visibility:           public
id:                   stm-containers-1.2.1.1-F7PPVEqIAyKHfbA5LNFRpZ
key:                  stm-containers-1.2.1.1-F7PPVEqIAyKHfbA5LNFRpZ
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  0496664e74fa2e62c44c520e69739ac8
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.1.1-F7PPVEqIAyKHfbA5LNFRpZ
depends:
    base-4.17.2.1 deferred-folds-0.9.18.6-HtaMriOUSPK6fN8KfiZp7
    focus-1.0.3.2-KaP0q2s4xqF1lVNITPnSzF
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    list-t-1.0.5.5-8lXUI1ymNIM7UUyeY3sOQP
    stm-hamt-1.2.1.1-2ZxrlZgJ3Yt5hBzTIVtAlN transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
